pub fn confined_preview(rendered: &str) -> StringExpand description
Build a bounded preview of a rendered value for inclusion in
TemplateRenderingError::Confined. Truncates on a UTF-8 char boundary.
pub fn confined_preview(rendered: &str) -> StringBuild a bounded preview of a rendered value for inclusion in
TemplateRenderingError::Confined. Truncates on a UTF-8 char boundary.