pub struct UnconfinedTemplate { /* private fields */ }Expand description
A templated field.
In many cases, components can be configured so that part of the component’s functionality can be
customized on a per-event basis. By using UnconfinedTemplate, users can specify either fixed
strings or templated strings. Templated strings use a common syntax to refer to fields in an
event that is used as the input data when rendering the template.
Implementations
Sourceimpl UnconfinedTemplate
impl UnconfinedTemplate
Sourcepub const fn with_tz_offset(self, tz_offset: Option<FixedOffset>) -> Self
pub const fn with_tz_offset(self, tz_offset: Option<FixedOffset>) -> Self
Set tz offset.
Sourcepub fn render<'a>(
&self,
event: impl Into<EventRef<'a>>,
) -> Result<Bytes, TemplateRenderingError>
pub fn render<'a>( &self, event: impl Into<EventRef<'a>>, ) -> Result<Bytes, TemplateRenderingError>
Renders the given template with data from the event, returning raw bytes.
Sourcepub fn render_string<'a>(
&self,
event: impl Into<EventRef<'a>>,
) -> Result<String, TemplateRenderingError>
pub fn render_string<'a>( &self, event: impl Into<EventRef<'a>>, ) -> Result<String, TemplateRenderingError>
Renders the given template with data from the event.
Sourcepub fn get_fields(&self) -> Option<Vec<String>>
pub fn get_fields(&self) -> Option<Vec<String>>
Returns the names of the fields that are rendered in this template.
Sourcepub fn literal_prefix(&self) -> &str
pub fn literal_prefix(&self) -> &str
Longest leading substring of the template source that is rendered
verbatim — no {{ field }} reference and no strftime specifier.
Sinks use this to derive a confinement boundary from the operator-authored portion of the template.
Sourcepub const fn is_empty(&self) -> bool
pub const fn is_empty(&self) -> bool
Returns true if this template string has a length of zero, and false otherwise.
Sourcepub const fn is_dynamic(&self) -> bool
pub const fn is_dynamic(&self) -> bool
A dynamic template string contains sections that depend on the input event or time.